==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/acl/lang/eo/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Robert Bogenschneider <bogi@uea.org>
 */
$lang['admin_acl']             = 'Administrado de Alirkontrola Listo (ACL)';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Uzanto';
$lang['acl_perms']             = 'Rajtoj por';
$lang['page']                  = 'Paĝo';
$lang['namespace']             = 'Nomspaco';
$lang['btn_select']            = 'Elekti';
$lang['p_user_id']             = 'Uzanto <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Uzanto <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bonvolu <b>enmeti uzanton aŭ grupon</b> en la suban agordilon por rigardi aŭ redakti la aron da rajtoj por la paĝo <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Bonvolu <b>enmeti uzanton aŭ grupon</b> en la suban agordilon por rigardi aŭ redakti la aron da rajtoj por la nomspaco <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Rimarko: tiuj rajtoj ne estas rekte difinitaj, sed ili herediĝas el aliaj pli supraj grupoj aŭ nomspacoj.';
$lang['p_isadmin']             = 'Rimarko: la elektita grupo aŭ uzanto ĉiam havas plenan rajtaron ĉar ĝi estas difinita kiel superuzanto.';
$lang['p_include']             = 'Plialtaj permesoj inkluzivas malpli altajn. La permesoj por Krei, Alŝuti kaj Forigi nur aplikeblas al nomspacoj, ne al paĝoj.';
$lang['current']               = 'Aktuala regularo ACL';
$lang['where']                 = 'Paĝo/Nomspaco';
$lang['who']                   = 'Uzanto/Grupo';
$lang['perm']                  = 'Rajtoj';
$lang['acl_perm0']             = 'Nenio';
$lang['acl_perm1']             = 'Legi';
$lang['acl_perm2']             = 'Redakti';
$lang['acl_perm4']             = 'Krei';
$lang['acl_perm8']             = 'Alŝuti';
$lang['acl_perm16']            = 'Forigi';
$lang['acl_new']               = 'Aldoni novan enmetaĵon';
$lang['acl_mod']               = 'Modifi enmetaĵon';

==> dokuwiki_0.0.20180422.a.orig.tar.gz: dokuwiki-2018-04-22a/lib/plugins/acl/lang/eo/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 */
$lang['admin_acl']             = 'Administrado de Alirkontrola Listo (ACL)';
$lang['acl_group']             = 'Grupo:';
$lang['acl_user']              = 'Uzanto:';
$lang['acl_perms']             = 'Rajtoj por';
$lang['page']                  = 'Paĝo';
$lang['namespace']             = 'Nomspaco';
$lang['btn_select']            = 'Elekti';
$lang['p_user_id']             = 'Uzanto <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Uzanto <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bonvolu <b>enmeti uzanton aŭ grupon</b> en la suban agordilon por rigardi aŭ redakti la aron da rajtoj por la paĝo <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Bonvolu <b>enmeti uzanton aŭ grupon</b> en la suban agordilon por rigardi aŭ redakti la aron da rajtoj por la nomspaco <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Rimarko: tiuj rajtoj ne estas rekte difinitaj, sed ili herediĝas el aliaj pli supraj grupoj aŭ nomspacoj.';
$lang['p_isadmin']             = 'Rimarko: la elektita grupo aŭ uzanto ĉiam havas plenan rajtaron ĉar ĝi estas difinita kiel superuzanto.';
$lang['p_include']             = 'Plialtaj permesoj inkluzivas malpli altajn. La permesoj por Krei, Alŝuti kaj Forigi nur aplikeblas al nomspacoj, ne al paĝoj.';
$lang['current']               = 'Aktuala regularo ACL';
$lang['where']                 = 'Paĝo/Nomspaco';
$lang['who']                   = 'Uzanto/Grupo';
$lang['perm']                  = 'Rajtoj';
$lang['acl_perm0']             = 'Nenio';
$lang['acl_perm1']             = 'Legi';
$lang['acl_perm2']             = 'Redakti';
$lang['acl_perm4']             = 'Krei';
$lang['acl_perm8']             = 'Alŝuti';
$lang['acl_perm16']            = 'Forigi';
$lang['acl_new']               = 'Aldoni novan enmetaĵon';
$lang['acl_mod']               = 'Modifi enmetaĵon';
